@@ -937,7 +937,7 @@ obj.ALC_level_3_3 <- function(Xcand, Xref, fit, mc.sample, parallel = FALSE, nco
 #' from the posterior distribution of \eqn{f_s(\bm{x}^{[s]}_{n_s+1})}
 #' based on the current design allows to compute \eqn{\tilde{\sigma}_L^{*2}(\bm{\xi};l,\bm{x})}.
 #' Inverse of covariance matrix is computed by the Sherman-Morrison formula.
-#' For details, see Heo and Sung (2023+, <arXiv:2309.11772>).
+#' For details, see Heo and Sung (2024, <\doi{https://doi.org/10.1080/00401706.2024.2376173}>).
 #'
 #' To search for the next acquisition \eqn{\bm{x^*}} by maximizing AL criterion,
 #' the gradient-based optimization can be used by \code{optim=TRUE}.
@@ -959,6 +959,7 @@ obj.ALC_level_3_3 <- function(Xcand, Xref, fit, mc.sample, parallel = FALSE, nco
 #' @param optim logical indicating whether to optimize AL criterion by \code{optim}'s gradient-based \code{L-BFGS-B} method. If \code{optim=TRUE}, \eqn{5 \times d} starting points are generated by Latin hypercube design for optimization. If \code{optim=FALSE}, AL criterion is optimized on the \code{Xcand}. Default is \code{TRUE}.
 #' @param parallel logical indicating whether to compute the AL criterion in parallel or not. If \code{parallel=TRUE}, parallel computation is utilized. Default is \code{FALSE}.
 #' @param ncore a number of core for parallel. It is only used if \code{parallel=TRUE}. Default is 1.
+#' @param trace logical indicating whether to print the computational time for each step. If \code{trace=TRUE}, the computation time for each step is printed. Default is \code{TRUE}.
 #' @return
 #' \itemize{
 #'   \item \code{ALC}: list of ALC criterion integrated on \code{Xref} when each data point on \code{Xcand} is added at each level \eqn{l} if \code{optim=FALSE}. If \code{optim=TRUE}, \code{ALC} returns \code{NULL}.
@@ -976,7 +977,7 @@ obj.ALC_level_3_3 <- function(Xcand, Xref, fit, mc.sample, parallel = FALSE, nco
 #' @importFrom doParallel registerDoParallel
 #' @importFrom doParallel stopImplicitCluster
 #' @usage ALC_RNAmf(Xref = NULL, Xcand = NULL, fit, mc.sample = 100,
-#' cost = NULL, optim = TRUE, parallel = FALSE, ncore = 1)
+#' cost = NULL, optim = TRUE, parallel = FALSE, ncore = 1, trace=TRUE)
 #' @export
 #' @examples
 #' \donttest{
@@ -1062,8 +1063,8 @@ obj.ALC_level_3_3 <- function(Xcand, Xref, fit, mc.sample, parallel = FALSE, nco
 #' )
 #' par(oldpar)}
 #'
-ALC_RNAmf <- function(Xref = NULL, Xcand = NULL, fit, mc.sample = 100, cost = NULL, optim = TRUE, parallel = FALSE, ncore = 1) {
-  t1 <- proc.time()[3]
+ALC_RNAmf <- function(Xref = NULL, Xcand = NULL, fit, mc.sample = 100, cost = NULL, optim = TRUE, parallel = FALSE, ncore = 1, trace=TRUE) {
+  t0 <- proc.time()
   ### check the object ###
   if (!inherits(fit, "RNAmf")) {
     stop("The object is not of class \"RNAmf\" \n")
@@ -1111,8 +1112,7 @@ ALC_RNAmf <- function(Xref = NULL, Xcand = NULL, fit, mc.sample = 100, cost = NU
     # if (ncol(Xcand) != dim(fit$fit1$X)[2]) stop("The dimension of candidate set should be equal to the dimension of the design")
 
     ### Calculate the deduced variance ###
-    cat("running starting points: \n")
-    time.start <- proc.time()[3]
+    t1 <- proc.time()
     if (parallel) {
       pseudointvar <- foreach(i = 1:nrow(Xcand), .combine = cbind) %dopar% {
         newx <- matrix(Xcand[i, ], nrow = 1)
@@ -1135,25 +1135,24 @@ ALC_RNAmf <- function(Xref = NULL, Xcand = NULL, fit, mc.sample = 100, cost = NU
         intvar2[i] <- obj.ALC_level_2(newx, Xref, fit, mc.sample)
       }
     }
-    print(proc.time()[3] - time.start)
+    t2 <-proc.time()
+    if(trace) cat("Calculating the deduced variance:", (t2 - t1)[3], "seconds\n")
 
     ### Find the next point ###
     if (optim) {
-      cat("running optim for level 1: \n")
-      time.start <- proc.time()[3]
       X.start <- matrix(Xcand[which.min(intvar1), ], nrow = 1)
       optim.out <- optim(X.start, obj.ALC_level_1, method = "L-BFGS-B", lower = 0, upper = 1, fit = fit, Xref = Xref, mc.sample = mc.sample, parallel = parallel, ncore = ncore)
       Xnext.1 <- optim.out$par
       ALC.1 <- optim.out$value
-      print(proc.time()[3] - time.start)
+      t3 <-proc.time()
+      if(trace) cat("Running optim for level 1:", (t3 - t2)[3], "seconds\n")
 
-      cat("running optim for level 2: \n")
-      time.start <- proc.time()[3]
       X.start <- matrix(Xcand[which.min(intvar2), ], nrow = 1)
       optim.out <- optim(X.start, obj.ALC_level_2, method = "L-BFGS-B", lower = 0, upper = 1, fit = fit, Xref = Xref, mc.sample = mc.sample, parallel = parallel, ncore = ncore)
       Xnext.2 <- optim.out$par
       ALC.2 <- optim.out$value
-      print(proc.time()[3] - time.start)
+      t4 <-proc.time()
+      if(trace) cat("Running optim for level 2:", (t4 - t3)[3], "seconds\n")
 
       ALCvalue <- c(Icurrent - ALC.1, Icurrent - ALC.2) / c(cost[1], cost[1] + cost[2])
       if (ALCvalue[2] > ALCvalue[1]) {
@@ -1226,8 +1225,7 @@ ALC_RNAmf <- function(Xref = NULL, Xcand = NULL, fit, mc.sample = 100, cost = NU
     # if (ncol(Xcand) != dim(fit$fit1$X)[2]) stop("The dimension of candidate set should be equal to the dimension of the design")
 
     ### Calculate the deduced variance ###
-    cat("running starting points: \n")
-    time.start <- proc.time()[3]
+    t1 <- proc.time()
     if (parallel) {
       pseudointvar <- foreach(i = 1:nrow(Xcand), .combine = cbind) %dopar% {
         newx <- matrix(Xcand[i, ], nrow = 1)
@@ -1254,33 +1252,31 @@ ALC_RNAmf <- function(Xref = NULL, Xcand = NULL, fit, mc.sample = 100, cost = NU
         intvar3[i] <- obj.ALC_level_3_3(newx, Xref, fit, mc.sample)
       }
     }
-    print(proc.time()[3] - time.start)
+    t2 <-proc.time()
+    if(trace) cat("Calculating the deduced variance:", (t2 - t1)[3], "seconds\n")
 
     ### Find the next point ###
     if (optim) {
-      cat("running optim for level 1: \n")
-      time.start <- proc.time()[3]
       X.start <- matrix(Xcand[which.min(intvar1), ], nrow = 1)
       optim.out <- optim(X.start, obj.ALC_level_3_1, method = "L-BFGS-B", lower = 0, upper = 1, fit = fit, Xref = Xref, mc.sample = mc.sample, parallel = parallel, ncore = ncore)
       Xnext.1 <- optim.out$par
       ALC.1 <- optim.out$value
-      print(proc.time()[3] - time.start)
+      t3 <-proc.time()
+      if(trace) cat("Running optim for level 1:", (t3 - t2)[3], "seconds\n")
 
-      cat("running optim for level 2: \n")
-      time.start <- proc.time()[3]
       X.start <- matrix(Xcand[which.min(intvar2), ], nrow = 1)
       optim.out <- optim(X.start, obj.ALC_level_3_2, method = "L-BFGS-B", lower = 0, upper = 1, fit = fit, Xref = Xref, mc.sample = mc.sample, parallel = parallel, ncore = ncore)
       Xnext.2 <- optim.out$par
       ALC.2 <- optim.out$value
-      print(proc.time()[3] - time.start)
+      t4 <-proc.time()
+      if(trace) cat("Running optim for level 2:", (t4 - t3)[3], "seconds\n")
 
-      cat("running optim for level 3: \n")
-      time.start <- proc.time()[3]
       X.start <- matrix(Xcand[which.min(intvar3), ], nrow = 1)
       optim.out <- optim(X.start, obj.ALC_level_3_3, method = "L-BFGS-B", lower = 0, upper = 1, fit = fit, Xref = Xref, mc.sample = mc.sample, parallel = parallel, ncore = ncore)
       Xnext.3 <- optim.out$par
       ALC.3 <- optim.out$value
-      print(proc.time()[3] - time.start)
+      t5 <-proc.time()
+      if(trace) cat("Running optim for level 3:", (t5 - t4)[3], "seconds\n")
 
       ALCvalue <- c(Icurrent - ALC.1, Icurrent - ALC.2, Icurrent - ALC.3) / c(cost[1], cost[1] + cost[2], cost[1] + cost[2] + cost[3])
       if (ALCvalue[3] > ALCvalue[2]) {
@@ -1320,5 +1316,5 @@ ALC_RNAmf <- function(Xref = NULL, Xcand = NULL, fit, mc.sample = 100, cost = NU
   if (parallel) stopImplicitCluster()
   if (optim) ALC <- NULL
 
-  return(list(ALC = ALC, cost = cost, Xcand = Xcand, chosen = chosen, time = proc.time()[3] - t1))
+  return(list(ALC = ALC, cost = cost, Xcand = Xcand, chosen = chosen, time = (proc.time() - t0)[3]))
 }
