@@ -44,7 +44,6 @@
 #' GP(X1, y1)
 #' }
 GP <- function(X, y, g = sqrt(.Machine$double.eps),
-               lower = 0.001, upper = 1000,
                Xscale = TRUE, Yscale = TRUE, constant = FALSE) {
   if (constant) {
     if (is.null(dim(X))) X <- matrix(X, ncol = 1)
@@ -58,10 +57,10 @@ GP <- function(X, y, g = sqrt(.Machine$double.eps),
       return(c(lower, upper))
     }
 
-    # hetGP way * 10^(d*2/3)
+    # hetGP way * 10^(d*3/4)
     XX <- (X - matrix(apply(X, 2, range)[1, ], nrow = nrow(X), ncol = ncol(X), byrow = TRUE)) %*% diag(1 / (apply(X, 2, range)[2, ] - apply(X, 2, range)[1, ]), ncol(X))
-    lower <- max(10^(ncol(XX) * 2 / 3) * apply(XX, 2, parbound)[1, ], 0.2)
-    upper <- 10^(ncol(XX) * 2 / 3) * apply(XX, 2, parbound)[2, ]
+    lower <- pmax(10^(ncol(XX) * 3 / 4) * apply(XX, 2, parbound)[1, ], 0.2)
+    upper <- 10^(ncol(XX) * 3 / 4) * apply(XX, 2, parbound)[2, ]
     init <- sqrt(lower * upper)
 
     # # hetGP way
@@ -137,10 +136,10 @@ GP <- function(X, y, g = sqrt(.Machine$double.eps),
       return(c(lower, upper))
     }
 
-    # hetGP way * 10^(d*2/3)
+    # hetGP way * 10^(d*3/4)
     XX <- (X - matrix(apply(X, 2, range)[1, ], nrow = nrow(X), ncol = ncol(X), byrow = TRUE)) %*% diag(1 / (apply(X, 2, range)[2, ] - apply(X, 2, range)[1, ]), ncol(X))
-    lower <- max(10^(ncol(XX) * 2 / 3) * apply(XX, 2, parbound)[1, ], 0.2)
-    upper <- 10^(ncol(XX) * 2 / 3) * apply(XX, 2, parbound)[2, ]
+    lower <- pmax(10^(ncol(XX) * 3 / 4) * apply(XX, 2, parbound)[1, ], 0.2)
+    upper <- 10^(ncol(XX) * 3 / 4) * apply(XX, 2, parbound)[2, ]
     init <- sqrt(lower * upper)
 
     # # hetGP way
